/*
** Module   : Spawner.java
** Abstract : define Spawner contract.
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- -------------------------------Description------------------------------------
** 001 MAG 20131118 First version.
** 002 CA  20140206 Refactored to make it unaware of the type of the P2J client beeing spawned.
*/

package com.goldencode.p2j.main;

/**
 * This interface is exported using a RemoteObject protocol and is designed as a communication 
 * gateway between the server handler and spawned client. 
 * 
 * @author mag
 *
 */
public interface Spawner
{
   /**
    * Notify when the client has started.
    * 
    * @param    uuid
    *           Remote client assigned identifier.
    * @param    data
    *           Custom data sent by the P2J client back to the server.
    */
   public void clientIsReady(String uuid, Object data);
   
   /**
    * Depending on the implementation, export custom data from the server back to the client.
    * 
    * @param    uuid
    *           Remote client assigned identifier.
    *
    * @return   Custom data sent by the server back to the client.
    */
   public Object exportData(String uuid);
   
   /**
    * Get a {@link TemporaryClient} worker which will do the work after authenticating on the P2J
    * server using the temporary credentials.
    * 
    * @param    uuid
    *           Remote client assigned identifier.
    * 
    * @return   See above.
    */
   public TemporaryClient getTemporaryClient(String uuid);
}
