/*
** Module   : SpawnerListener.java
** Abstract : define the Spawner listener contract.
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- -------------------------------Description------------------------------------
** 001 MAG 20131119 First version.
** 002 CA  20140206 Refactored to hide the web client related behavior.
*/

package com.goldencode.p2j.main;

/**
 * This interface should be implemented by callers which communicate with a spawned process 
 * (client) in order to provide custom data to the client and notify the server that the client 
 * process has started.
 */
public interface SpawnerListener
{
   /**
    * Notify when the client has started.
    * 
    * @param    data
    *           Custom data sent by the P2J client back to the server.
    */
   public void clientIsReady(Object data);
   
   /**
    * Depending on the implementation, receive custom data from the server.
    * 
    * @return   Custom data sent by the server back to the client.
    */
   public Object getServerData();
   
   /**
    * Get a {@link TemporaryClient} worker which will do the work after authenticating on the P2J
    * server using the temporary credentials.
    * 
    * @return   See above.
    */
   public TemporaryClient getTemporaryClient();
}
