/*
** Module   : JavaLaunchTask.java
** Abstract : Launcher for java-style tasks.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20140206 First version.
*/

package com.goldencode.p2j.scheduler;

import java.lang.reflect.*;
import java.util.logging.*;

import com.goldencode.p2j.util.*;

/**
 * Launcher for java-style tasks.
 */
class JavaLaunchTask
implements Runnable
{
   /** Logger. */
   private static final Logger LOG = LogHelper.getLogger(JavaLaunchTask.class);

   /** The target class. */
   private final String cls;
   
   /** The target method. */
   private final String method;
   
   /**
    * Configure this launcher.
    * 
    * @param    cls
    *           The target class.
    * @param    method
    *           The target method.
    */
   public JavaLaunchTask(String cls, String method)
   {
      this.cls = cls;
      this.method = method;
   }

   /**
    * Invoke the {@link #method} from the specified {@link #cls class}.  If the method is not 
    * static, a new instance of {@link #cls} type will be created.
    */
   @Override
   public void run()
   {
      try
      {
         Class<?> clazz = Class.forName(cls);
         Method mthd = clazz.getMethod(method);
         Object instance = (Modifier.isStatic(mthd.getModifiers())) ? null 
                                                                    : clazz.newInstance();
         
         mthd.invoke(instance);
      }
      catch (Exception e)
      {
         if (LOG.isLoggable(Level.SEVERE))
         {
            final String msg = String.format("Could not launch java job %s.%s", cls, method);
            LOG.logp(Level.SEVERE, "JavaLaunchTask", "run", msg);
         }
      }
   }
}