/*
** Module   : ProcessLaunchTask.java
** Abstract : Launcher for jobs targeting a P2J process.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20140206 First version.
*/

package com.goldencode.p2j.scheduler;

import com.goldencode.p2j.main.*;
import com.goldencode.p2j.util.*;

/**
 * Implementation for launching a P2J process; this class must be executed under the server's
 * context.  If the P2J process is linked with an appserver, it will delegate the launching to
 * {@link AppServerLauncher#launch}.  Else, it will use the {@link ProcessClientSpawner 
 * spawner} infrastructure to start a P2J client.
 */
class ProcessLaunchTask
implements Runnable
{
   /** The P2J process subject ID. */
   private final String process;

   /**
    * Create a new launcher task for the given process.
    * 
    * @param    process
    *           The process subject ID.
    */
   public ProcessLaunchTask(String process)
   {
      this.process = process;
   }
   
   /**
    * Calls {@link ProcessClientSpawner#launch(String)} to launch this P2J {@link #process}.
    */
   @Override
   public void run()
   {
      ProcessClientSpawner.launch(process);
   }
   
   /**
    * Get the string representation of this runner.
    */
   @Override
   public String toString()
   {
      return String.format("Launcher for process '%s'.", process);
   }
}